@@ -4,6 +4,7 @@ from lyrebird import application
 from flask import request, jsonify, abort, stream_with_context
 import json
 import time
+from ...handlers.encoder_decoder_handler import encoders_decoders
 
 
 class Flow(Resource):
@@ -14,7 +15,10 @@ class Flow(Resource):
     def get(self, id):
         for item in context.application.cache.items():
             if item['id'] == id:
-                return application.make_ok_response(data=item)
+                # Import decoder for decoding the requested content
+                display_item = {}
+                encoders_decoders.decoder_handler(item, output=display_item)
+                return application.make_ok_response(data=display_item)
         return abort(400, 'Request not found')
 
 
@@ -41,13 +45,13 @@ class FlowList(Resource):
                 response=dict(
                     code=item['response']['code'],
                     mock=item['response']['headers'].get('lyrebird', 'proxy'),
-                    modified=item['response']['headers'].get('lyrebird_modified', '')
+                    modified=item['request']['headers'].get('lyrebird_modified') or item['response']['headers'].get('lyrebird_modified', '')
                 )if item.get('response') else {}
             )
             req_list.append(info)
 
         def gen():
-            yield json.dumps(req_list)
+            yield json.dumps(req_list, ensure_ascii=False)
         return context.make_streamed_response(gen)
 
     def delete(self):
@@ -69,9 +73,7 @@ class FlowList(Resource):
                     break
         dm = context.application.data_manager
 
-        flow_list = context.application.cache.items()
-        for flow in flow_list:
-            if flow['id'] in _ids:
-                dm.save_data(flow)
+        for flow in record_items:
+            dm.save_data(flow)
 
         return context.make_ok_response()
